@@ -4,7 +4,6 @@ use serde::de::{
     IntoDeserializer,
 };
 use std::{
-    array::IntoIter,
     fmt::Display,
     fs::File,
     io::{BufReader, Cursor, Read, Seek},
@@ -134,10 +133,10 @@ where
             Event::Data(v) => visitor.visit_byte_buf(v.into_owned()),
             Event::Date(v) if self.in_plist_value => {
                 visitor.visit_enum(MapAccessDeserializer::new(MapDeserializer::new(
-                    IntoIter::new([(DATE_NEWTYPE_STRUCT_NAME, v.to_rfc3339())]),
+                    [(DATE_NEWTYPE_STRUCT_NAME, v.to_xml_format())].into_iter(),
                 )))
             }
-            Event::Date(v) => visitor.visit_string(v.to_rfc3339()),
+            Event::Date(v) => visitor.visit_string(v.to_xml_format()),
             Event::Integer(v) => {
                 if let Some(v) = v.as_unsigned() {
                     visitor.visit_u64(v)
@@ -150,7 +149,7 @@ where
             Event::Real(v) => visitor.visit_f64(v),
             Event::String(v) => visitor.visit_string(v.into_owned()),
             Event::Uid(v) if self.in_plist_value => visitor.visit_enum(MapAccessDeserializer::new(
-                MapDeserializer::new(IntoIter::new([(UID_NEWTYPE_STRUCT_NAME, v.get())])),
+                MapDeserializer::new([(UID_NEWTYPE_STRUCT_NAME, v.get())].into_iter()),
             )),
             Event::Uid(v) => visitor.visit_u64(v.get()),
         }
@@ -184,7 +183,7 @@ where
             }
             OptionMode::StructField => {
                 // None struct values are ignored so if we're here the value must be Some.
-                self.with_option_mode(OptionMode::Explicit, |this| Ok(visitor.visit_some(this)?))
+                self.with_option_mode(OptionMode::Explicit, |this| visitor.visit_some(this))
             }
             OptionMode::Explicit => {
                 expect!(self.events.next(), EventKind::StartDictionary);
@@ -214,7 +213,7 @@ where
         V: de::Visitor<'de>,
     {
         if name == VALUE_NEWTYPE_STRUCT_NAME {
-            self.enter_plist_value(|this| this.deserialize_any(visitor))
+            self.enter_plist_value(|this| visitor.visit_newtype_struct(this))
         } else {
             visitor.visit_newtype_struct(self)
         }
@@ -392,7 +391,7 @@ where
             OptionMode::Explicit
         };
         self.de
-            .with_option_mode(option_mode, |this| Ok(seed.deserialize(this)?))
+            .with_option_mode(option_mode, |this| seed.deserialize(this))
     }
 
     fn size_hint(&self) -> Option<usize> {
