@@ -2,11 +2,11 @@ use serde::{
     de::{Deserialize, DeserializeOwned},
     ser::Serialize,
 };
-use std::{collections::BTreeMap, fmt::Debug, fs::File, io::Cursor, path::Path};
+use std::{collections::BTreeMap, fmt::Debug, fs::File, io::Cursor};
 
 use crate::{
     stream::{private::Sealed, Event, OwnedEvent, Writer},
-    Date, Deserializer, Dictionary, Error, Integer, Serializer, Uid, Value,
+    Data, Date, Deserializer, Dictionary, Error, Integer, Serializer, Uid, Value,
 };
 
 struct VecWriter {
@@ -130,6 +130,7 @@ struct DogInner {
     b: usize,
     c: Vec<String>,
     d: Option<Uid>,
+    e: Data,
 }
 
 #[test]
@@ -149,6 +150,7 @@ fn dog() {
             b: 12,
             c: vec!["a".to_string(), "b".to_string()],
             d: Some(Uid::new(42)),
+            e: Data::new(vec![20, 22]),
         }],
     });
 
@@ -170,6 +172,8 @@ fn dog() {
         Event::EndCollection,
         Event::String("d".into()),
         Event::Uid(Uid::new(42)),
+        Event::String("e".into()),
+        Event::Data(vec![20, 22].into()),
         Event::EndCollection,
         Event::EndCollection,
         Event::EndCollection,
@@ -183,7 +187,7 @@ fn dog() {
 fn frog() {
     let frog = Animal::Frog(
         Ok("hello".to_owned()),
-        Some(vec![1.0, 2.0, 3.14159, 0.000000001, 1.27e31]),
+        Some(vec![1.0, 2.0, std::f64::consts::PI, 0.000000001, 1.27e31]),
     );
 
     let comparison = &[
@@ -199,7 +203,7 @@ fn frog() {
         Event::StartArray(Some(5)),
         Event::Real(1.0),
         Event::Real(2.0),
-        Event::Real(3.14159),
+        Event::Real(std::f64::consts::PI),
         Event::Real(0.000000001),
         Event::Real(1.27e31),
         Event::EndCollection,
@@ -342,11 +346,11 @@ struct TypeWithDate {
 
 #[test]
 fn type_with_date() {
-    let date = Date::from_rfc3339("1920-01-01T00:10:00Z").unwrap();
+    let date = Date::from_xml_format("1920-01-01T00:10:00Z").unwrap();
 
     let obj = TypeWithDate {
         a: Some(28),
-        b: Some(date.clone()),
+        b: Some(date),
     };
 
     let comparison = &[
@@ -586,7 +590,7 @@ fn deserialise_old_enum_unit_variant_encoding() {
 
 #[test]
 fn deserialize_dictionary_xml() {
-    let reader = File::open(&Path::new("./tests/data/xml.plist")).unwrap();
+    let reader = File::open("./tests/data/xml.plist").unwrap();
     let dict: Dictionary = crate::from_reader(reader).unwrap();
 
     check_common_plist(&dict);
@@ -603,7 +607,7 @@ fn deserialize_dictionary_xml() {
 
 #[test]
 fn deserialize_dictionary_binary() {
-    let reader = File::open(&Path::new("./tests/data/binary.plist")).unwrap();
+    let reader = File::open("./tests/data/binary.plist").unwrap();
     let dict: Dictionary = crate::from_reader(reader).unwrap();
 
     check_common_plist(&dict);
@@ -619,7 +623,7 @@ fn check_common_plist(dict: &Dictionary) {
     assert_eq!(lines.len(), 2);
     assert_eq!(
         lines[0].as_string().unwrap(),
-        "It is a tale told by an idiot,"
+        "It is a tale told by an idiot,     "
     );
     assert_eq!(
         lines[1].as_string().unwrap(),
@@ -634,9 +638,9 @@ fn check_common_plist(dict: &Dictionary) {
 
     // Boolean elements
 
-    assert_eq!(dict.get("IsTrue").unwrap().as_boolean().unwrap(), true);
+    assert!(dict.get("IsTrue").unwrap().as_boolean().unwrap());
 
-    assert_eq!(dict.get("IsNotFalse").unwrap().as_boolean().unwrap(), false);
+    assert!(!dict.get("IsNotFalse").unwrap().as_boolean().unwrap());
 
     // Data
 
@@ -651,7 +655,7 @@ fn check_common_plist(dict: &Dictionary) {
 
     assert_eq!(
         dict.get("Birthdate").unwrap().as_date().unwrap(),
-        Date::from_rfc3339("1981-05-16T11:32:06Z").unwrap()
+        Date::from_xml_format("1981-05-16T11:32:06Z").unwrap()
     );
 
     // Real
@@ -699,7 +703,7 @@ fn check_common_plist(dict: &Dictionary) {
 
 #[test]
 fn deserialize_dictionary_binary_nskeyedarchiver() {
-    let reader = File::open(&Path::new("./tests/data/binary_NSKeyedArchiver.plist")).unwrap();
+    let reader = File::open("./tests/data/binary_NSKeyedArchiver.plist").unwrap();
     let dict: Dictionary = crate::from_reader(reader).unwrap();
 
     assert_eq!(
@@ -825,7 +829,7 @@ fn dictionary_serialize_xml() {
     inner_dict.insert("ThirdKey".to_owned(), Value::Real(1.234));
     inner_dict.insert(
         "FourthKey".to_owned(),
-        Value::Date(Date::from_rfc3339("1981-05-16T11:32:06Z").unwrap()),
+        Value::Date(Date::from_xml_format("1981-05-16T11:32:06Z").unwrap()),
     );
 
     // Top-level dictionary.
@@ -862,7 +866,9 @@ fn dictionary_serialize_xml() {
 \t\t<key>FirstKey</key>
 \t\t<string>FirstValue</string>
 \t\t<key>SecondKey</key>
-\t\t<data>\n\t\tChQeKA==\n\t\t</data>
+\t\t<data>
+\t\tChQeKA==
+\t\t</data>
 \t\t<key>ThirdKey</key>
 \t\t<real>1.234</real>
 \t\t<key>FourthKey</key>
@@ -879,3 +885,37 @@ fn dictionary_serialize_xml() {
 
     assert_eq!(xml, comparison);
 }
+
+#[test]
+fn empty_array_and_dictionary_serialize_to_xml() {
+    #[derive(Serialize, Default)]
+    struct Empty {
+        vec: Vec<String>,
+        map: BTreeMap<String, String>,
+    }
+
+    // Serialize dictionary as an XML plist.
+    let mut buf = Cursor::new(Vec::new());
+    crate::to_writer_xml(&mut buf, &Empty::default()).unwrap();
+    let buf = buf.into_inner();
+    let xml = std::str::from_utf8(&buf).unwrap();
+
+    let comparison = "<?xml version=\"1.0\" encoding=\"UTF-8\"?>
+<!DOCTYPE plist PUBLIC \"-//Apple//DTD PLIST 1.0//EN\" \"http://www.apple.com/DTDs/PropertyList-1.0.dtd\">
+<plist version=\"1.0\">
+<dict>
+\t<key>vec</key>
+\t<array/>
+\t<key>map</key>
+\t<dict/>
+</dict>
+</plist>";
+
+    assert_eq!(xml, comparison);
+}
+
+#[test]
+fn serde_yaml_to_value() {
+    let value: Value = serde_yaml::from_str("true").unwrap();
+    assert_eq!(value, Value::Boolean(true));
+}
